@@ -72,6 +72,7 @@ int GGZCoreRoom::removeHook(const GGZCoreRoomEvent event, const unsigned int id)
 	return ggzcore_room_remove_event_hook_id(m_room, (GGZRoomEvent)event, id);
 }
 
+/*
 int GGZCoreRoom::init(GGZServer* server, const unsigned int id, const char* name, const unsigned int game, const char* description, const char *category)
 {
 #ifdef KGGZ_PATCH_C_AND_R
@@ -80,6 +81,12 @@ int GGZCoreRoom::init(GGZServer* server, const unsigned int id, const char* name
 	return ggzcore_room_init(m_room, server, id, name, game, description);
 #endif
 }
+*/
+
+/*int GGZCoreRoom::id()
+{
+	return ggzcore_room_get_id(m_room);
+}*/
 
 const char* GGZCoreRoom::name()
 {
@@ -185,9 +192,14 @@ int GGZCoreRoom::listTables(const int type, const char global)
 	return ggzcore_room_list_tables(m_room, type, global);
 }
 
-int GGZCoreRoom::chat(const GGZChatType opcode, const char* player, const char* message)
+int GGZCoreRoom::chat(ChatTypes opcode, const char* player, const char* message)
 {
-	return ggzcore_room_chat(m_room, opcode, player, message);
+	return ggzcore_room_chat(m_room, (GGZChatType)opcode, player, message);
+}
+
+int GGZCoreRoom::admin(AdminTypes opcode, const char* player, const char* reason)
+{
+	return ggzcore_room_admin(m_room, (GGZAdminType)opcode, player, reason);
 }
 
 int GGZCoreRoom::launchTable(GGZTable* table)
@@ -229,6 +241,11 @@ int GGZCoreRoom::sendData(char* buffer)
 	return 0;
 }
 
+bool GGZCoreRoom::closed()
+{
+	return (ggzcore_room_get_closed(m_room) == 1);
+}
+
 GGZRoom* GGZCoreRoom::room()
 {
 	return m_room;
