@@ -49,7 +49,8 @@ class GGZCoreRoom
 			tableleavefail = GGZ_TABLE_LEAVE_FAIL,
 			playerlag = GGZ_PLAYER_LAG,
 			stats = GGZ_PLAYER_STATS,
-			count = GGZ_PLAYER_COUNT
+			count = GGZ_PLAYER_COUNT,
+			perms = GGZ_PLAYER_PERMS
 		};
 
 		enum ChatTypes
@@ -62,6 +63,13 @@ class GGZCoreRoom
 			chatunknown = GGZ_CHAT_UNKNOWN
 		};
 
+		enum AdminTypes
+		{
+			admingag = GGZ_ADMIN_GAG,
+			adminungag = GGZ_ADMIN_UNGAG,
+			adminkick = GGZ_ADMIN_KICK
+		};
+
 		/**
 		 * Constructor */
 		GGZCoreRoom();
@@ -88,7 +96,11 @@ class GGZCoreRoom
 
 		/**
 		 * Initialize a room with the required information. */
-		int init(GGZServer* server, const unsigned int id, const char* name, const unsigned int game, const char* description, const char *category);
+		//int init(GGZServer* server, const unsigned int id, const char* name, const unsigned int game, const char* description, const char *category);
+
+		/**
+		 * Room identifier. */
+		//int id();
 
 		/**
 		 * Return the name of the room. */
@@ -141,11 +153,20 @@ class GGZCoreRoom
 
 		/**
 		 * Send a chat message to the other players. */
-		int chat(const GGZChatType opcode, const char* player, const char* message);
+		int chat(ChatTypes opcode, const char* player, const char* message);
+
+		/**
+		 * Performs some administrative actions. */
+		int admin(AdminTypes opcode, const char* player, const char* reason);
+
 		/**
 		 * Send other data. */
 		int sendData(char* buffer);
 
+		/**
+		 * Check if room is closed alrady. */
+		bool closed();
+
 		/**
 		 * Return the internal GGZRoom structure */
 		GGZRoom* room();
