@@ -50,7 +50,8 @@ class GGZCoreServer
 			statechange = GGZ_STATE_CHANGE,
 			channelconnected = GGZ_CHANNEL_CONNECTED,
 			channelready = GGZ_CHANNEL_READY,
-			channelfail = GGZ_CHANNEL_FAIL
+			channelfail = GGZ_CHANNEL_FAIL,
+			rooms = GGZ_SERVER_ROOMS_CHANGED
 		};
 
 		/**
@@ -129,10 +130,11 @@ class GGZCoreServer
 		GGZCoreRoom* room();
 		/**
 		 * Return an explicitely given room. */
+		GGZCoreRoom* room(/*const unsigned int number*/GGZRoom *ggzroom);
 		GGZCoreRoom* room(const unsigned int number);
 		/**
 		 * Join a room. */
-		int joinRoom(const unsigned int number);
+		int joinRoom(/*const unsigned int number*/GGZRoom *room);
 
 		/**
 		 * The number of available game types. */
