@@ -113,6 +113,7 @@ KGGZ::KGGZ(QWidget *parent, const char *name)
 	m_workspace = new KGGZWorkspace(this, "workspace");
 
 	connect(m_workspace->widgetChat(), SIGNAL(signalChat(QString, QString, int)), SLOT(slotChat(QString, QString, int)));
+	connect(m_workspace->widgetChat(), SIGNAL(signalAdmin(int, QString, QString)), SLOT(slotAdmin(int, QString, QString)));
 	connect(m_workspace->widgetUsers(), SIGNAL(signalChat(QString, QString, int)), SLOT(slotChat(QString, QString, int)));
 	connect(m_workspace->widgetLogo(), SIGNAL(signalInfo()), SLOT(menuGameInfo()));
 
@@ -297,6 +298,9 @@ void KGGZ::slotConnectedStart()
 	m_save_host = addr.toString();
 	KGGZDEBUG("Host resolved to: %s\n", m_save_host.utf8().data());
 
+	delete m_dns;
+	m_dns = NULL;
+
 	kggzserver = new GGZCoreServer();
 	attachServerCallbacks();
 	kggzserver->logSession(QString("%1/.ggz/kggz.xml-log").arg(QDir::homeDirPath()).utf8());
@@ -592,6 +596,9 @@ void KGGZ::listPlayers()
 			case GGZCorePlayer::admin:
 				type = KGGZUsers::assignadmin;
 				break;
+			case GGZCorePlayer::host:
+				type = KGGZUsers::assignhost;
+				break;
 			case GGZCorePlayer::bot:
 				type = KGGZUsers::assignbot;
 				break;
@@ -783,6 +790,9 @@ void KGGZ::roomCollector(unsigned int id, const void* data)
 		case GGZCoreRoom::count:
 			roomnumber = *(int*)data;
 			break;
+		case GGZCoreRoom::perms:
+			player = QString((char*)data);
+			break;
 	}
 
 	switch(id)
@@ -838,10 +848,10 @@ void KGGZ::roomCollector(unsigned int id, const void* data)
 		case GGZCoreRoom::enter:
 			KGGZDEBUG("enter\n");
 			event = (GGZRoomChangeEventData*)data;
-			if(event->from_room == -2) fromroom = "(unknown origin)";
-			else if(event->from_room == -1) fromroom = i18n("first room after login");
+			/*if(event->from_room == -2) fromroom = i18n("(unknown origin)");
+			else*/ if(event->from_room == NULL) fromroom = i18n("first room after login");
 			else fromroom = QString("from room %1").arg(kggzserver->room(event->from_room)->name());
-			buffer = QString("%1 enters the room (%2).").arg(
+			buffer = i18n("%1 enters the room (%2).").arg(
 				event->player_name).arg(
 				fromroom);
 			//buffer.append(event->player_name);
@@ -850,17 +860,17 @@ void KGGZ::roomCollector(unsigned int id, const void* data)
 			m_workspace->widgetUsers()->add(event->player_name);
 			m_workspace->widgetChat()->chatline()->addPlayer(event->player_name);
 			//if(m_grubby) m_grubby->addPlayer(event->player_name);
-			roomnumber = event->to_room;
-			kggzroom = kggzserver->room(roomnumber);
+			roomnumber = ggzcore_server_get_room_num(kggzserver->server(), event->to_room);
+			kggzroom = new GGZCoreRoom(event->to_room); //kggzserver->room(roomnumber);
 			emit signalRoomChanged(kggzroom->name(), kggzroom->gametype()->protocolEngine(), roomnumber, kggzroom->countPlayers());
 			break;
 		case GGZCoreRoom::leave:
 			KGGZDEBUG("leave\n");
 			event = (GGZRoomChangeEventData*)data;
-			if(event->to_room == -2) toroom = "(unknown destination)";
-			else if(event->to_room == -1) toroom = i18n("disconnect from server");
+			/*if(event->to_room == -2) toroom = i18n("(unknown destination)");
+			else*/ if(event->to_room == NULL) toroom = i18n("disconnect from server");
 			else toroom = QString("to room %1").arg(kggzserver->room(event->to_room)->name());
-			buffer = QString("%1 has left the room (%2).").arg(
+			buffer = i18n("%1 has left the room (%2).").arg(
 				event->player_name).arg(
 				toroom);
 			//buffer.append(event->player_name);
@@ -869,8 +879,8 @@ void KGGZ::roomCollector(unsigned int id, const void* data)
 			m_workspace->widgetUsers()->remove(event->player_name);
 			KGGZDEBUG("remove from chatline\n");
 			m_workspace->widgetChat()->chatline()->removePlayer(event->player_name);
-			roomnumber = event->from_room;
-			kggzroom = kggzserver->room(roomnumber);
+			roomnumber = ggzcore_server_get_room_num(kggzserver->server(), event->from_room);
+			kggzroom = new GGZCoreRoom(event->from_room); //kggzserver->room(roomnumber);
 			emit signalRoomChanged(kggzroom->name(), kggzroom->gametype()->protocolEngine(), roomnumber, kggzroom->countPlayers());
 			KGGZDEBUG("Leave room event: ready\n");
 			break;
@@ -941,6 +951,10 @@ void KGGZ::roomCollector(unsigned int id, const void* data)
 				ggzcore_gametype_get_prot_engine(ggzcore_room_get_gametype(room)),
 				roomnumber, ggzcore_room_get_num_players(room));
 			break;
+		case GGZCoreRoom::perms:
+			KGGZDEBUG("perms!\n");
+			KGGZDEBUG("Player: %s\n", player.utf8().data());
+			break;
 		default:
 			KGGZDEBUG("unknown\n");
 			break;
@@ -958,6 +972,7 @@ void KGGZ::serverCollector(unsigned int id, const void* data)
 #endif
 	int roomnumber;
 	GGZMotdEventData *motd;
+	const GGZErrorEventData *error = (GGZErrorEventData*)data;
 
 	emit signalActivity(ACTIVITY_ROOM);
 
@@ -1048,7 +1063,9 @@ void KGGZ::serverCollector(unsigned int id, const void* data)
 			break;
 		case GGZCoreServer::loginfail:
 			KGGZDEBUG("loginfail\n");
-			KMessageBox::error(this, i18n("Login refused!"), i18n("Error!"));
+			KMessageBox::error(this,
+				i18n("Login refused! Reason: %1").arg(error->message),
+				i18n("Error!"));
 			m_killserver = 1;
 			menuConnect();
 			break;
@@ -1069,10 +1086,22 @@ void KGGZ::serverCollector(unsigned int id, const void* data)
 			emit signalMenu(MENUSIG_ROOMLIST);
 			for(int i = 0; i < kggzserver->countRooms(); i++)
 			{
+				bool roominstalled = true;
+				GGZCoreGametype *gametype = kggzserver->room(i)->gametype();
+				if(gametype->name())
+				{
+					GGZCoreModule *module = new GGZCoreModule();
+					module->init(gametype->name(), gametype->protocolVersion(), gametype->protocolEngine());
+					if(module->count() == 0) roominstalled = false;
+					delete module;
+				}
+
 				emit signalRoom(kggzserver->room(i)->name(),
 					kggzserver->room(i)->gametype()->protocolEngine(),
 					kggzserver->room(i)->category(),
-					kggzserver->room(i)->countPlayers());
+					kggzserver->room(i)->countPlayers(),
+					!kggzserver->room(i)->closed(),
+					roominstalled);
 				m_roommap[kggzserver->room(i)->gametype()->protocolEngine()] = i;
 			}
 
@@ -1193,6 +1222,30 @@ void KGGZ::serverCollector(unsigned int id, const void* data)
 		case GGZCoreServer::players:
 			emit signalPlayers(kggzserver->countPlayers());
 			break;
+		case GGZCoreServer::rooms:
+			KGGZDEBUG("[reconf] rooms changed\n");
+			emit signalReconfiguration();
+			for(int i = 0; i < kggzserver->countRooms(); i++)
+			{
+				bool roominstalled = true;
+				GGZCoreGametype *gametype = kggzserver->room(i)->gametype();
+				if(gametype->name())
+				{
+					GGZCoreModule *module = new GGZCoreModule();
+					module->init(gametype->name(), gametype->protocolVersion(), gametype->protocolEngine());
+					if(module->count() == 0) roominstalled = false;
+					delete module;
+				}
+
+				emit signalRoom(kggzserver->room(i)->name(),
+					kggzserver->room(i)->gametype()->protocolEngine(),
+					kggzserver->room(i)->category(),
+					kggzserver->room(i)->countPlayers(),
+					!kggzserver->room(i)->closed(),
+					roominstalled);
+				m_roommap[kggzserver->room(i)->gametype()->protocolEngine()] = i;
+			}
+			break;
 		default:
 			KGGZDEBUG("unknown\n");
 			break;
@@ -1237,6 +1290,27 @@ GGZHookReturn KGGZ::hookOpenCollector(unsigned int id, const void* event_data, c
 	return GGZ_HOOK_OK;
 }
 
+void KGGZ::slotAdmin(int action, QString player, QString text)
+{
+	if((kggzserver) && (kggzroom))
+	{
+		KGGZDEBUG("Admin action on: %s\n", player.utf8().data());
+
+		switch(action)
+		{
+			case KGGZChat::ADMIN_GAG:
+				kggzroom->admin(GGZCoreRoom::admingag, player, NULL);
+				break;
+			case KGGZChat::ADMIN_UNGAG:
+				kggzroom->admin(GGZCoreRoom::adminungag, player, NULL);
+				break;
+			case KGGZChat::ADMIN_KICK:
+				kggzroom->admin(GGZCoreRoom::adminkick, player, text);
+				break;
+		}
+	}
+}
+
 void KGGZ::slotChat(QString text, QString player, int mode)
 {
 	if((kggzserver) && (kggzroom))
@@ -1245,13 +1319,13 @@ void KGGZ::slotChat(QString text, QString player, int mode)
 		switch(mode)
 		{
 			case KGGZChat::RECEIVE_CHAT:
-				kggzroom->chat(GGZ_CHAT_NORMAL, player, text);
+				kggzroom->chat(GGZCoreRoom::chatnormal, player, text);
 				break;
 			case KGGZChat::RECEIVE_TABLE:
-				kggzroom->chat(GGZ_CHAT_TABLE, player, text);
+				kggzroom->chat(GGZCoreRoom::chattable, player, text);
 				break;
 			case KGGZChat::RECEIVE_ANNOUNCE:
-				if(kggzroom->chat(GGZ_CHAT_ANNOUNCE, NULL, text) < 0)
+				if(kggzroom->chat(GGZCoreRoom::chatannounce, NULL, text) < 0)
 				{
 					m_workspace->widgetChat()->receive(NULL,
 						i18n("Only administrators are allowed to broadcast messages."),
@@ -1259,10 +1333,10 @@ void KGGZ::slotChat(QString text, QString player, int mode)
 				}
 				break;
 			case KGGZChat::RECEIVE_BEEP:
-				kggzroom->chat(GGZ_CHAT_BEEP, player, text);
+				kggzroom->chat(GGZCoreRoom::chatbeep, player, text);
 				break;
 			case KGGZChat::RECEIVE_PERSONAL:
-				kggzroom->chat(GGZ_CHAT_PERSONAL, player, text);
+				kggzroom->chat(GGZCoreRoom::chatprivate, player, text);
 				break;
 		}
 	}
@@ -1334,6 +1408,7 @@ void KGGZ::attachServerCallbacks()
 	kggzserver->addHook(GGZCoreServer::channelready, &KGGZ::hookOpenCollector, (void*)kggzservercallback);
 	kggzserver->addHook(GGZCoreServer::channelfail, &KGGZ::hookOpenCollector, (void*)kggzservercallback);
 	kggzserver->addHook(GGZCoreServer::players, &KGGZ::hookOpenCollector, (void*)kggzservercallback);
+	kggzserver->addHook(GGZCoreServer::rooms, &KGGZ::hookOpenCollector, (void*)kggzservercallback);
 }
 
 void KGGZ::detachServerCallbacks()
@@ -1358,6 +1433,8 @@ void KGGZ::detachServerCallbacks()
 	kggzserver->removeHook(GGZCoreServer::channelconnected, &KGGZ::hookOpenCollector);
 	kggzserver->removeHook(GGZCoreServer::channelready, &KGGZ::hookOpenCollector);
 	kggzserver->removeHook(GGZCoreServer::channelfail, &KGGZ::hookOpenCollector);
+	kggzserver->removeHook(GGZCoreServer::players, &KGGZ::hookOpenCollector);
+	kggzserver->removeHook(GGZCoreServer::rooms, &KGGZ::hookOpenCollector);
 }
 
 void KGGZ::attachGameCallbacks()
@@ -1793,11 +1870,17 @@ void KGGZ::menuGameRules()
 
 void KGGZ::menuRoom(int room)
 {
+	//int id;
+
 	if(room >= 0)
 	{
 		if(kggzserver)
 		{
-			kggzserver->joinRoom(room);
+			GGZCoreRoom *r = kggzserver->room(room);
+			//id = r->id();
+			GGZRoom *ggzroom = r->room();
+
+			kggzserver->joinRoom(/*id*/ggzroom);
 			if((m_workspace) && (m_workspace->widgetChat()))
 			{
 				m_workspace->widgetChat()->init();
