@@ -132,7 +132,8 @@ class KGGZ : public QWidget
 		// Emitted to dis/enable menu items
 		void signalMenu(int signal);
 		// Emitted to announce new room
-		void signalRoom(const char *roomname, const char *protocolname, const char *category, int numplayers);
+		void signalRoom(const char *roomname, const char *protocolname, const char *category,
+			int numplayers, bool enabled, bool installed);
 		// Emitted to announce room player changes
 		void signalRoomChanged(const char *roomname, const char *protocolname, int roomnumber, int numplayers);
 		// Emitted to change window caption
@@ -145,6 +146,8 @@ class KGGZ : public QWidget
 		void signalActivity(int activity);
 		// Emitted on player count change
 		void signalPlayers(int players);
+		// Emitted when rooms are added or removed
+		void signalReconfiguration();
 
 	public slots:
 		// Connect to a game server
@@ -188,6 +191,8 @@ class KGGZ : public QWidget
 		void slotConnectedStart();
 		// Receive chat message
 		void slotChat(QString text, QString player, int mode);
+		// Receive administrative actions
+		void slotAdmin(int action, QString player, QString text);
 		// Send grubby requests
 		void slotGrubby(QString grubby, QString argument, int id);
 		// Prepares a game launch
