@@ -65,15 +65,22 @@
 #ifdef WITH_HOWL
 #include <sys/types.h>
 #include <howl.h>
+//#else
 #endif
+// FIXME: always included even if not used (due to moc's #ifndef handling)
+#include <dnssd/query.h>
 
 // GGZCore++ includes
 #include "GGZCoreConfio.h"
 
+// Metaserver is hardcoded for the time being
+// FIXME: use kcm_ggz settings and/or libmeta cache (~/.ggz/metaserver.cache)
+#define PRIMARY_METASERVER "live.ggzgamingzone.org"
+
 #ifdef WITH_HOWL
 static KGGZConnect *connectobj = NULL;
 #endif
-static QString connectstr = QString::null;
+static QString connectstr;
 
 /* Constructor: set up a small dialog for connections; provide server profile list */
 KGGZConnect::KGGZConnect(QWidget *parent, const char *name)
@@ -286,11 +293,11 @@ void KGGZConnect::slotLoadProfile(int profile)
 		profile_select->insertItem(QPixmap(KGGZ_DIRECTORY "/images/icons/metaserver.png"), i18n("GGZ Meta Server"));
 		if(defaultserver == i18n("GGZ Meta Server"))
 			profile_select->setCurrentItem(0);
-#ifdef WITH_HOWL
+//#ifdef WITH_HOWL
 		profile_select->insertItem(QPixmap(KGGZ_DIRECTORY "/images/icons/langame.png"), i18n("LAN Game"));
 		if(defaultserver == i18n("LAN Game"))
 			profile_select->setCurrentItem(1);
-#endif
+//#endif
 		if(defaultserver.isNull())
 		{
 			modifyServerList(i18n("Default Stable Server"), 1);
@@ -374,7 +381,8 @@ void KGGZConnect::slotAccept()
 		m_sock = new QSocket();
 		connect(m_sock, SIGNAL(connected()), SLOT(slotWrite()));
 		connect(m_sock, SIGNAL(readyRead()), SLOT(slotRead()));
-		m_sock->connectToHost("live.ggzgamingzone.org", 15689);
+		connect(m_sock, SIGNAL(error(int)), SLOT(slotError(int)));
+		m_sock->connectToHost(PRIMARY_METASERVER, 15689);
 	}
 	else if(input_host->text() == i18n("Autodetect"))
 	{
@@ -568,23 +576,34 @@ void KGGZConnect::slotRead()
 
 	if(!rdata.isEmpty())
 	{
-		list = list.split(':', rdata);
-		if(list.count() == 3)
+		list = list.split("\n", rdata);
+		if(list.count() >= 1)
 		{
-			host = *(list.at(1));
-			host = host.right(host.length() - 2);
-			port = *(list.at(2));
-			close();
-			emit signalConnect(host, port.toInt(), input_name->text(), input_password->text(), m_loginmode);
+			list = list.split(':', list[0]);
+			if(list.count() == 3)
+			{
+				host = *(list.at(1));
+				host = host.right(host.length() - 2);
+				port = *(list.at(2));
+				close();
+				emit signalConnect(host, port.toInt(), input_name->text(),
+					input_password->text(), m_loginmode);
+			}
 		}
 	}
+
+	delete m_sock;
 }
 
 void KGGZConnect::slotWrite()
 {
 	QString s;
 
-	s = QString("query://ggz/connection/%1\n").arg(KGGZVERSION);
+	//s = QString("query://ggz/connection/%1\n").arg(KGGZVERSION);
+	// starting from 0.0.14, the URI query doesn't support versioning anymore
+	// we just pick the first line of the answer
+	// for everything else, the KGGZMeta dialog provides selection
+	s = QString("query://ggz/connection\n");
 	m_sock->writeBlock(s.utf8(), s.length());
 	m_sock->flush();
 }
@@ -625,6 +644,9 @@ static sw_result breply(sw_discovery session, sw_discovery_oid oid,
 		if(ret)
 		{
 			KMessageBox::error(connectobj, i18n("Resolving failed."), i18n("Zeroconf error"));
+			//connectobj->button_ok->setEnabled(true);
+			connectobj->showEvent(NULL);
+			connectstr = "";
 			return -1;
 		}
 	}
@@ -633,15 +655,33 @@ static sw_result breply(sw_discovery session, sw_discovery_oid oid,
 }
 #endif
 
+void KGGZConnect::slotService(DNSSD::RemoteService::Ptr ptr)
+{
+#ifndef WITH_HOWL
+	ptr->resolve();
+	connectstr = QString("ggz://%1:%2").arg(ptr->hostName()).arg(ptr->port());
+#endif
+}
+
+void KGGZConnect::slotServiceFinished()
+{
+#ifndef WITH_HOWL
+	KMessageBox::error(this, i18n("Resolving failed."), i18n("Zeroconf error"));
+	button_ok->setEnabled(true);
+	connectstr = "";
+#endif
+}
+
 void KGGZConnect::zeroconfQuery()
 {
+	connectstr = QString::null;
+
 #ifdef WITH_HOWL
 	int ret;
 	sw_discovery session;
 	sw_discovery_oid oid;
 
 	connectobj = this;
-	connectstr = QString::null;
 
 	ret = sw_discovery_init(&session);
 	if(ret != SW_OKAY)
@@ -657,12 +697,40 @@ void KGGZConnect::zeroconfQuery()
 		sw_discovery_read_socket(session);
 		kapp->eventLoop()->processEvents(QEventLoop::AllEvents);
 	}
+#else
+	DNSSD::Query *query = new DNSSD::Query("_ggz._tcp", QString::null/*"local."*/);
+	connect(query,
+		SIGNAL(serviceAdded(DNSSD::RemoteService::Ptr)),
+		SLOT(slotService(DNSSD::RemoteService::Ptr)));
+	connect(query, SIGNAL(finished()), SLOT(slotServiceFinished()));
+	query->startQuery();
+
+	while(connectstr.isNull())
+	{
+		kapp->eventLoop()->processEvents(QEventLoop::AllEvents);
+	}
+
+	delete query;
+#endif
+
+	if(connectstr.isEmpty()) return;
 
 	KURL url(connectstr);
 
 	close();
-	KMessageBox::information(this, i18n("A GGZ server was found on %1.").arg(connectstr), i18n("Zeroconf success"));
-	emit signalConnect(url.host(), url.port(), input_name->text(), input_password->text(), m_loginmode);
-#endif
+	KMessageBox::information(this,
+		i18n("A GGZ server was found on %1.").arg(connectstr),
+		i18n("Zeroconf success"));
+	emit signalConnect(url.host(), url.port(), input_name->text(),
+		input_password->text(), m_loginmode);
+}
+
+void KGGZConnect::slotError(int code)
+{
+	KMessageBox::error(this,
+		i18n("The GGZ metaserver could not be contacted."),
+		i18n("Connection"));
+	button_ok->setEnabled(true);
+	delete m_sock;
 }
 
