@@ -59,22 +59,24 @@ int main(int argc, char **argv)
 		KGGZVERSION,
 		I18N_NOOP("Your most desired KDE network games launcher and chat system."),
 		KAboutData::License_GPL,
-		"Copyright (C) 2000 - 2005 Josef Spillner",
+		"Copyright (C) 2000 - 2006 Josef Spillner",
 		I18N_NOOP("KGGZ is a frontend for the GGZ Gaming Zone"),
-		"http://www.ggzgamingzone.org/clients/kggz",
+		"http://www.ggzgamingzone.org/clients/kde",
 		"josef@ggzgamingzone.org");
 
 	// forgotten anybody? tell me.
 	aboutData->addAuthor("Josef Spillner", I18N_NOOP("KDE port of the client"), "josef@ggzgamingzone.org");
-	aboutData->addCredit("Brian Cox", I18N_NOOP("(GGZ team)"), "bcox@users.sourceforge.net", "http://ggz.sourceforge.net");
-	aboutData->addCredit("Rich Gade", I18N_NOOP("(GGZ team)"), "rgade@users.sourceforge.net", "http://ggz.sourceforge.net");
-	aboutData->addCredit("Brent Hendricks", I18N_NOOP("(GGZ team)"), "bmh@users.sourceforge.net", "http://ggz.sourceforge.net");
-	aboutData->addCredit("Justin Zaun", I18N_NOOP("(GGZ team)"), "jzaun@users.sourceforge.net", "http://ggz.sourceforge.net");
-	aboutData->addCredit("Doug Hudson", I18N_NOOP("(GGZ team)"), "djh@users.sourceforge.net", "http://ggz.sourceforge.net");
-	aboutData->addCredit("Ismael Orenstein", I18N_NOOP("(GGZ team)"), "perdig@users.sourceforge.net", "http://ggz.sourceforge.net");
-	aboutData->addCredit("Dan Papasian", I18N_NOOP("(GGZ team)"), "bugg@users.sourceforge.net", "http://ggz.sourceforge.net");
-	aboutData->addCredit("Ricardo Quesada", I18N_NOOP("(GGZ team)"), "riq@core-sdi.com", "http://teg.sourceforge.net");
-	aboutData->addCredit("Jason Short", I18N_NOOP("(GGZ team)"), "jshort@devon.dhs.org", "http://ggz.sourceforge.net");
+	aboutData->addCredit("Brian Cox", I18N_NOOP("(GGZ team)"), "bcox@users.sourceforge.net");
+	aboutData->addCredit("Rich Gade", I18N_NOOP("(GGZ team)"), "rgade@users.sourceforge.net");
+	aboutData->addCredit("Brent Hendricks", I18N_NOOP("(GGZ team)"), "bmh@users.sourceforge.net");
+	aboutData->addCredit("Justin Zaun", I18N_NOOP("(GGZ team)"), "jzaun@users.sourceforge.net");
+	aboutData->addCredit("Doug Hudson", I18N_NOOP("(GGZ team)"), "djh@users.sourceforge.net");
+	aboutData->addCredit("Ismael Orenstein", I18N_NOOP("(GGZ team)"), "perdig@users.sourceforge.net");
+	aboutData->addCredit("Dan Papasian", I18N_NOOP("(GGZ team)"), "bugg@users.sourceforge.net");
+	aboutData->addCredit("Ricardo Quesada", I18N_NOOP("(GGZ team)"), "riq@core-sdi.com");
+	aboutData->addCredit("Jason Short", I18N_NOOP("(GGZ team)"), "jdorje@ggzgamingzone.org");
+	aboutData->addCredit("Roger Light", I18N_NOOP("(GGZ team)"), "oojah@ggzgamingzone.org");
+	aboutData->addCredit("Helg Bredow", I18N_NOOP("(GGZ team)"), "helg@ggzgamingzone.org");
 	aboutData->setTranslator(I18N_NOOP("TRANSLATOR-NAME"), I18N_NOOP("TRANSLATOR-EMAIL"));
 
 	// process command line options
@@ -87,6 +89,9 @@ int main(int argc, char **argv)
 	kggzbase = new KGGZBase();
 	a.setMainWidget(kggzbase);
 
+	// We need to preload ggzcore message translations
+	KGlobal::locale()->insertCatalogue("ggzcore");
+
 	// open default URI
 	if(args->count())
 	{
