@@ -79,7 +79,9 @@ KGGZUsers::KGGZUsers(QWidget *parent, const char *name)
 		i18n("Banned"), creditbanned);
 
 	m_menu_info = new QPopupMenu(NULL);
-	m_menu_info->insertItem(i18n("Record"), inforecord);
+	m_menu_info->insertItem(i18n("Player"), infoplayer);
+	m_menu_info->insertItem(i18n("Game results"), inforecord);
+	m_menu_info->insertItem(i18n("Grant host privileges"), infoadminhost);
 
 	connect(this,
 		SIGNAL(rightButtonPressed(QListViewItem*, const QPoint&, int)),
@@ -231,6 +233,9 @@ void KGGZUsers::display(QString playername)
 		case assignadmin:
 			pixmap = "admin.png";
 			break;
+		case assignhost:
+			pixmap = "host.png";
+			break;
 	}
 
 	rolepixmap = QPixmap(KGGZ_DIRECTORY "/images/icons/players/" + pixmap);
@@ -310,13 +315,85 @@ void KGGZUsers::setLag(QString playername, int lagvalue)
 	lag(player(playername), lagvalue);
 }
 
+void KGGZUsers::displayPlayer(QString playername)
+{
+	QString playerlevel;
+	int role;
+	QString text;
+
+	role = m_roles[playername];
+
+	switch(role)
+	{
+		case assignplayer:
+			playerlevel = i18n("Registered player");
+			break;
+		case assignguest:
+			playerlevel = i18n("Guest player (anonymous/not registered)");
+			break;
+		case assignbot:
+			playerlevel = i18n("Chat bot");
+			break;
+		case assignadmin:
+			playerlevel = i18n("Server administrator");
+			break;
+		case assignhost:
+			playerlevel = i18n("Host player");
+			break;
+	}
+
+	text = i18n("Information about %1:\n").arg(playername);
+	text += i18n("Player level: %1\n").arg(playerlevel);
+
+	KMessageBox::information(this, text, i18n("Player information"));
+}
+
+void KGGZUsers::displayRecord(GGZCorePlayer *player)
+{
+	bool hasrecord, hasrating, hasranking, hashighscore;
+	int wins, losses, ties, forfeits;
+	int rating, ranking, highscore;
+	QString text;
+
+	hasrecord = player->hasRecord();
+	hasrating = player->hasRating();
+	hasranking = player->hasRanking();
+	hashighscore = player->hasHighscore();
+
+	wins = player->recordWins();
+	losses = player->recordLosses();
+	ties = player->recordTies();
+	forfeits = player->recordForfeits();
+
+	highscore = player->highscore();
+	ranking = player->ranking();
+	rating = player->rating();
+
+	text = i18n("Information about %1:\n").arg(player->name());
+	if(hasrecord)
+	{
+		text = text + i18n("Wins: %1\nLosses: %2\n").arg(wins).arg(losses);
+		text = text + i18n("Ties: %1\nForfeits: %2\n").arg(ties).arg(forfeits);
+	}
+	if(hasrating)
+		text = text + i18n("Rating: %1\n").arg(rating);
+	if(hasranking)
+		text = text + i18n("Ranking: %1\n").arg(ranking);
+	if(hashighscore)
+		text = text + i18n("Highscore: %1\n").arg(highscore);
+	if((!hasrecord) && (!hasrating) && (!hasranking) && (!hashighscore))
+	{
+		text = text + i18n("No statistics found.\n").arg(ranking);
+	}
+
+	KMessageBox::information(this, text, i18n("Player game information"));
+}
+
 void KGGZUsers::slotInformation(int id)
 {
 	QListViewItem *tmp;
-	int wins, losses, ties, forfeits;
-	int rating, ranking, highscore;
-	QString playername, text;
 	GGZCorePlayer *player, *tmpplayer;
+	QString playername;
 
 	Q_UNUSED(id);
 
@@ -338,26 +415,9 @@ void KGGZUsers::slotInformation(int id)
 	}
 	if(!player) return;
 
-	wins = player->recordWins();
-	losses = player->recordLosses();
-	ties = player->recordTies();
-	forfeits = player->recordForfeits();
-
-	highscore = player->highscore();
-	ranking = player->ranking();
-	rating = player->rating();
-
-	text = i18n("Information about %1:\n").arg(playername);
-	text = text + i18n("Wins: %1\nLosses: %2\n").arg(wins).arg(losses);
-	text = text + i18n("Ties: %1\nForfeits: %2\n").arg(ties).arg(forfeits);
-	if(rating)
-		text = text + i18n("Rating: %1\n").arg(rating);
-	if(ranking)
-		text = text + i18n("Ranking: %1\n").arg(ranking);
-	if(highscore)
-		text = text + i18n("Highscore: %1\n").arg(highscore);
-
-	KMessageBox::information(this, text, i18n("Player information"));
+	if(id == infoplayer) displayPlayer(playername);
+	else if(id == inforecord) displayRecord(player);
+	else if(id == infoadminhost) adminHost(player);
 }
 
 void KGGZUsers::setRoom(GGZCoreRoom *room)
@@ -382,3 +442,13 @@ void KGGZUsers::slotContext(int id)
 	}
 }
 
+void KGGZUsers::adminHost(GGZCorePlayer *player)
+{
+	bool ret;
+	
+	ret = player->grantPermission(GGZCorePlayer::roomsadmin);
+	if(!ret) KMessageBox::sorry(this,
+		i18n("Player privileges could not be changed"),
+		i18n("Player management"));
+}
+
